@@ -123,19 +123,13 @@ e_cal_backend_ews_populate_windows_zones (void)
 		tokens = g_strsplit ((gchar *) ical, " ", 0);
 		tokens_len = g_strv_length (tokens);
 		if (tokens_len == 1) {
-			if (!g_hash_table_lookup (msdn_to_ical, msdn))
-				g_hash_table_insert (msdn_to_ical, g_strdup ((gchar *) msdn), g_strdup ((gchar *) ical));
-
-			if (!g_hash_table_lookup (ical_to_msdn, ical))
-				g_hash_table_insert (ical_to_msdn, g_strdup ((gchar *) ical), g_strdup ((gchar *) msdn));
+			g_hash_table_insert (msdn_to_ical, g_strdup ((gchar *) msdn), g_strdup ((gchar *) ical));
+			g_hash_table_insert (ical_to_msdn, g_strdup ((gchar *) ical), g_strdup ((gchar *) msdn));
 		} else {
 			gint j;
 			for (j = 0; j < tokens_len; j++) {
-				if (!g_hash_table_lookup (msdn_to_ical, msdn))
-					g_hash_table_insert (msdn_to_ical, g_strdup ((gchar *) msdn), g_strdup (tokens[j]));
-
-				if (!g_hash_table_lookup (ical_to_msdn, tokens[j]))
-					g_hash_table_insert (ical_to_msdn, g_strdup (tokens[j]), g_strdup ((gchar *) msdn));
+				g_hash_table_insert (msdn_to_ical, g_strdup ((gchar *) msdn), g_strdup (tokens[j]));
+				g_hash_table_insert (ical_to_msdn, g_strdup (tokens[j]), g_strdup ((gchar *) msdn));
 			}
 		}
 
@@ -216,6 +210,37 @@ e_cal_backend_ews_tz_util_get_ical_equivalent (const gchar *msdn_tz_location)
 	return ical_tz_location;
 }
 
+EwsCalendarConvertData *
+ews_calendar_convert_data_new (void)
+{
+	return g_new0 (EwsCalendarConvertData, 1);
+}
+
+void
+ews_calendar_convert_data_free (EwsCalendarConvertData *convert_data)
+{
+	if (convert_data != NULL) {
+		if (convert_data->connection != NULL)
+			g_clear_object (&convert_data->connection);
+		if (convert_data->comp != NULL)
+			g_clear_object (&convert_data->comp);
+		if (convert_data->old_comp != NULL)
+			g_clear_object (&convert_data->old_comp);
+		if (convert_data->default_zone != NULL)
+			icaltimezone_free (convert_data->default_zone, TRUE);
+		if (convert_data->icalcomp != NULL)
+			icalcomponent_free (convert_data->icalcomp);
+
+		g_free (convert_data->item_id);
+		g_free (convert_data->change_key);
+		g_free (convert_data->user_email);
+		g_free (convert_data->response_type);
+		g_slist_free_full (convert_data->users, g_free);
+
+		g_free (convert_data);
+	}
+}
+
 /*
  * Iterate over the icalcomponent properties and collect attendees
  */
