@@ -1422,20 +1422,9 @@ sync_updated_items (CamelEwsFolder *ews_folder,
 
 	for (l = updated_items; l != NULL; l = g_slist_next (l)) {
 		EEwsItem *item = (EEwsItem *) l->data;
-		const EwsId *id;
+		const EwsId *id = e_ews_item_get_id (item);
 		CamelMessageInfo *mi;
 
-		if (!item)
-			continue;
-
-		id = e_ews_item_get_id (item);
-		if (!id) {
-			g_warning ("%s: Missing ItemId for item type %d (subject:%s)", G_STRFUNC, e_ews_item_get_item_type (item),
-				e_ews_item_get_subject (item) ? e_ews_item_get_subject (item) : "???");
-			g_object_unref (item);
-			continue;
-		}
-
 		/* Compare the item_type from summary as the updated items seems to
 		 * arrive as generic types while its not the case */
 		mi = camel_folder_summary_get (folder->summary, id->id);
@@ -1544,14 +1533,6 @@ sync_created_items (CamelEwsFolder *ews_folder,
 
 		id = e_ews_item_get_id (item);
 		item_type = e_ews_item_get_item_type (item);
-
-		if (!id) {
-			g_warning ("%s: Missing ItemId for item type %d (subject:%s)", G_STRFUNC, item_type,
-				e_ews_item_get_subject (item) ? e_ews_item_get_subject (item) : "???");
-			g_object_unref (item);
-			continue;
-		}
-
 		/* created_msg_ids are items other than generic item. We fetch them
 		 * separately since the property sets vary */
 		/* FIXME: Do we need to handle any other item types
@@ -1884,18 +1865,7 @@ ews_append_message_sync (CamelFolder *folder,
 	e_ews_folder_id_free (fid);
 	g_free (folder_id);
 
-	if (camel_ews_summary_add_message (folder->summary, itemid, changekey, info, message)) {
-		CamelFolderChangeInfo *changes;
-
-		changes = camel_folder_change_info_new ();
-
-		camel_folder_change_info_add_uid (changes, itemid);
-
-		if (camel_folder_change_info_changed (changes))
-			camel_folder_changed (folder, changes);
-
-		camel_folder_change_info_free (changes);
-	}
+	camel_ews_summary_add_message (folder->summary, itemid, changekey, info, message);
 
 	if (appended_uid)
 		*appended_uid = itemid;
@@ -2019,8 +1989,8 @@ ews_transfer_messages_to_sync (CamelFolder *source,
 
 			clone = camel_message_info_clone (info);
 
-			if (camel_ews_summary_add_message (destination->summary, id->id, id->change_key, clone, message))
-				camel_folder_change_info_add_uid (changes, id->id);
+			camel_ews_summary_add_message (destination->summary, id->id, id->change_key, clone, message);
+			camel_folder_change_info_add_uid (changes, id->id);
 
 			camel_message_info_unref (clone);
 			camel_message_info_unref (info);
@@ -2402,9 +2372,6 @@ ews_folder_constructed (GObject *object)
 	gchar *host;
 	gchar *user;
 
-	/* Chain up to parent's method. */
-	G_OBJECT_CLASS (camel_ews_folder_parent_class)->constructed (object);
-
 	folder = CAMEL_FOLDER (object);
 	full_name = camel_folder_get_full_name (folder);
 	parent_store = camel_folder_get_parent_store (folder);
