@@ -36,7 +36,6 @@
 #include <shell/e-shell-window.h>
 
 #include "server/e-ews-connection.h"
-#include "server/e-ews-connection-utils.h"
 #include "server/e-source-ews-folder.h"
 
 #include "e-ews-edit-folder-permissions.h"
@@ -265,13 +264,6 @@ struct _EEwsConfigUtilsAuthenticatorClass {
 	GObjectClass parent_class;
 };
 
-static gboolean
-ews_config_utils_authenticator_get_without_password (ESourceAuthenticator *auth)
-{
-	EEwsConfigUtilsAuthenticator *authenticator = (EEwsConfigUtilsAuthenticator *) auth;
-	return e_ews_connection_utils_get_without_password (authenticator->ews_settings);
-}
-
 static ESourceAuthenticationResult
 ews_config_utils_authenticator_try_password_sync (ESourceAuthenticator *auth,
                                                   const GString *password,
@@ -366,10 +358,7 @@ e_ews_config_utils_authenticator_class_init (EEwsConfigUtilsAuthenticatorClass *
 static void
 e_ews_config_utils_authenticator_authenticator_init (ESourceAuthenticatorInterface *iface)
 {
-	iface->get_without_password =
-		ews_config_utils_authenticator_get_without_password;
-	iface->try_password_sync =
-		ews_config_utils_authenticator_try_password_sync;
+	iface->try_password_sync = ews_config_utils_authenticator_try_password_sync;
 }
 
 static void
