@@ -48,6 +48,8 @@ struct _EEwsFolderPrivate {
 	gboolean foreign;
 };
 
+static GObjectClass *parent_class = NULL;
+
 static void
 e_ews_folder_dispose (GObject *object)
 {
@@ -55,7 +57,8 @@ e_ews_folder_dispose (GObject *object)
 
 	g_return_if_fail (E_IS_EWS_FOLDER (folder));
 
-	G_OBJECT_CLASS (e_ews_folder_parent_class)->dispose (object);
+	if (parent_class->dispose)
+		(* parent_class->dispose) (object);
 }
 
 static void
@@ -89,7 +92,11 @@ e_ews_folder_finalize (GObject *object)
 		priv->parent_fid = NULL;
 	}
 
-	G_OBJECT_CLASS (e_ews_folder_parent_class)->finalize (object);
+	g_free (priv);
+	folder->priv = NULL;
+
+	if (parent_class->finalize)
+		(* parent_class->finalize) (object);
 }
 
 static void
@@ -97,7 +104,7 @@ e_ews_folder_class_init (EEwsFolderClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	g_type_class_add_private (klass, sizeof (EEwsFolderPrivate));
+	parent_class = g_type_class_peek_parent (klass);
 
 	object_class->dispose = e_ews_folder_dispose;
 	object_class->finalize = e_ews_folder_finalize;
@@ -106,10 +113,15 @@ e_ews_folder_class_init (EEwsFolderClass *klass)
 static void
 e_ews_folder_init (EEwsFolder *folder)
 {
-	folder->priv = G_TYPE_INSTANCE_GET_PRIVATE (folder, E_TYPE_EWS_FOLDER, EEwsFolderPrivate);
-	folder->priv->error = NULL;
-	folder->priv->folder_type = E_EWS_FOLDER_TYPE_UNKNOWN;
-	folder->priv->foreign = FALSE;
+	EEwsFolderPrivate *priv;
+
+	/* allocate internal structure */
+	priv = g_new0 (EEwsFolderPrivate, 1);
+	folder->priv = priv;
+
+	priv->error = NULL;
+	priv->folder_type = E_EWS_FOLDER_TYPE_UNKNOWN;
+	priv->foreign = FALSE;
 }
 
 static gboolean
